@@ -518,20 +518,3 @@ class EasyImageList:
             interact(_one_by_one_widget)
         else:
             self._popup_one_by_one()
-
-    def to_neptune(self):
-        """
-        Sends a image list to neptune (http://neptune.ml)
-        :return:
-        """
-        import neptune
-        ctx = neptune.Context()
-        channel_name = 'images_{}'
-        channel_count = 0
-        for i, image in enumerate(self.images):
-            if i % 100 == 0:
-                channel_count += 1
-                ctx.channel_send(
-                    channel_name.format(channel_count), neptune.Image(name=image.name,
-                                                                      description=str(image.label),
-                                                                      data=image.image))
